import {
  select,
  forceSimulation,
  forceManyBody,
  forceLink,
  forceCenter,
} from 'd3';

import { nodes, links } from './data';

const svg = select('#container');
const width = +svg.attr('width');
const height = +svg.attr('height');
const centerX = width / 2;
const centerY = height / 2;

const simulation = forceSimulation(nodes)
  .force('charge', forceManyBody().strength(-2000))
  .force('link', forceLink(links))
  .force('center', forceCenter(centerX, centerY));

const circles = svg
  .selectAll('circle')
  .data(nodes)
  .enter()
  .append('circle')
  .attr('fill', 'gray')
  .attr('r', (node) => node.size);

const text = svg
  .selectAll('text')
  .data(nodes)
  .enter()
  .append('text')
  .attr('text-anchor', 'middle')
  .attr('alignment-baseline', 'middle')
  .text((node) => node.id);

const lines = svg
  .selectAll('line')
  .data(links)
  .enter()
  .append('line')
  .attr('stroke', 'black');

simulation.on('tick', () => {
  circles.attr('cx', (node) => node.x).attr('cy', (node) => node.y);
  text.attr('x', (node) => node.x).attr('y', (node) => node.y);

  lines
    .attr('x1', (link) => link.source.x)
    .attr('y1', (link) => link.source.y)
    .attr('x2', (link) => link.target.x)
    .attr('y2', (link) => link.target.y);
});
